@@ -1,13 +1,15 @@
 from ._version import __author__, __author_email__, __version__
 from .formula import Formula
+from .materializers import FactorValues
 from .model_matrix import ModelMatrix
 from .sugar import model_matrix
 
 __all__ = [
-    '__author__',
-    '__author_email__',
-    '__version__',
-    'Formula',
-    'ModelMatrix',
-    'model_matrix',
+    "__author__",
+    "__author_email__",
+    "__version__",
+    "Formula",
+    "ModelMatrix",
+    "model_matrix",
+    "FactorValues",
 ]
