@@ -1,11 +1,13 @@
 from .enums import NAAction
 from .evaluated_factor import EvaluatedFactor
+from .factor_values import FactorValues
 from .scoped_factor import ScopedFactor
 from .scoped_term import ScopedTerm
 
 __all__ = [
-    'EvaluatedFactor',
-    'NAAction',
-    'ScopedFactor',
-    'ScopedTerm',
+    "EvaluatedFactor",
+    "FactorValues",
+    "NAAction",
+    "ScopedFactor",
+    "ScopedTerm",
 ]
