@@ -1,6 +1,21 @@
-class Term:
+from typing import Iterable, TYPE_CHECKING
 
-    def __init__(self, factors):
+if TYPE_CHECKING:
+    from .factor import Factor  # pragma: no cover
+
+
+class Term:
+    """
+    Represents a "term" of a formula.
+
+    A "term" is a product of "factors" (represented by `Factor`) instances, and
+    a formula is made up of a sum of terms.
+
+    Attributes:
+        factors: The set of factors to be multipled to form the term.
+    """
+
+    def __init__(self, factors: Iterable["Factor"]):
         self.factors = set(factors)
 
     def __mul__(self, other):
@@ -13,11 +28,13 @@ class Term:
         return tuple(factor.expr for factor in sorted(self.factors))
 
     def __hash__(self):
-        return hash(self._tuple)
+        return hash(str(self))
 
     def __eq__(self, other):
         if isinstance(other, Term):
             return self._tuple == other._tuple
+        if isinstance(other, str):
+            return repr(self) == other
         return NotImplemented
 
     def __lt__(self, other):
@@ -30,4 +47,4 @@ class Term:
         return NotImplemented
 
     def __repr__(self):
-        return ':'.join(self._tuple)
+        return ":".join(self._tuple)
